@@ -11,7 +11,7 @@
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
@@ -52,7 +52,7 @@
 /* The poll() emulation on OS/X doesn't handle fds=NULL, nfds=0,
  * so we prefer our own poll emulation.
  */
-#ifdef _POLL_EMUL_H_
+#if defined(_POLL_EMUL_H_) || defined(BROKEN_POLL)
 #undef HAVE_POLL
 #endif
    
@@ -1946,6 +1946,8 @@ g_main_current_source (void)
  * </programlisting></informalexample>
  *
  * Return value: %TRUE if the source has been destroyed
+ *
+ * Since: 2.12
  */
 gboolean
 g_source_is_destroyed (GSource *source)
@@ -3782,7 +3784,7 @@ g_child_watch_source_init (void)
  * <literal>g_spawn...</literal> when the %G_SPAWN_DO_NOT_REAP_CHILD
  * flag is used.
  *
- * Note that on platforms where #GPid must be explicitely closed
+ * Note that on platforms where #GPid must be explicitly closed
  * (see g_spawn_close_pid()) @pid must not be closed while the
  * source is still active. Typically, you will want to call
  * g_spawn_close_pid() in the callback function for the source.
@@ -3828,7 +3830,7 @@ g_child_watch_source_new (GPid pid)
  * Sets a function to be called when the child indicated by @pid exits, at a
  * default priority, #G_PRIORITY_DEFAULT.
  * 
- * Note that on platforms where #GPid must be explicitely closed
+ * Note that on platforms where #GPid must be explicitly closed
  * (see g_spawn_close_pid()) @pid must not be closed while the
  * source is still active. Typically, you will want to call
  * g_spawn_close_pid() in the callback function for the source.
@@ -3872,7 +3874,7 @@ g_child_watch_add_full (gint            priority,
  * Sets a function to be called when the child indicated by @pid exits, at a
  * default priority, #G_PRIORITY_DEFAULT.
  * 
- * Note that on platforms where #GPid must be explicitely closed
+ * Note that on platforms where #GPid must be explicitly closed
  * (see g_spawn_close_pid()) @pid must not be closed while the
  * source is still active. Typically, you will want to call
  * g_spawn_close_pid() in the callback function for the source.
