@@ -1016,13 +1016,55 @@ param_override_values_cmp (GParamSpec   *pspec,
   return g_param_values_cmp (ospec->overridden, value1, value2);
 }
 
+static void
+param_gtype_init (GParamSpec *pspec)
+{
+}
+
+static void
+param_gtype_set_default (GParamSpec *pspec,
+			 GValue     *value)
+{
+  value->data[0].v_long = G_TYPE_NONE;
+}
+
+static gboolean
+param_gtype_validate (GParamSpec *pspec,
+		      GValue     *value)
+{
+  GParamSpecGType *tspec = G_PARAM_SPEC_GTYPE (pspec);
+  GType gtype = value->data[0].v_long;
+  guint changed = 0;
+  
+  if (tspec->is_a_type != G_TYPE_NONE && !g_type_is_a (gtype, tspec->is_a_type))
+    {
+      value->data[0].v_long = G_TYPE_NONE;
+      changed++;
+    }
+  
+  return changed;
+}
+
+static gint
+param_gtype_values_cmp (GParamSpec   *pspec,
+			const GValue *value1,
+			const GValue *value2)
+{
+  GType p1 = value1->data[0].v_long;
+  GType p2 = value2->data[0].v_long;
+
+  /* not much to compare here, try to at least provide stable lesser/greater result */
+
+  return p1 < p2 ? -1 : p1 > p2;
+}
+
 /* --- type initialization --- */
 GType *g_param_spec_types = NULL;
 
 void
 g_param_spec_types_init (void)	
 {
-  const guint n_types = 21;
+  const guint n_types = 22;
   GType type, *spec_types, *spec_types_bound;
 
   g_param_spec_types = g_new0 (GType, n_types);
@@ -1042,7 +1084,7 @@ g_param_spec_types_init (void)
       param_char_validate,	/* value_validate */
       param_int_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamChar", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamChar"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_CHAR);
   }
@@ -1060,7 +1102,7 @@ g_param_spec_types_init (void)
       param_uchar_validate,	/* value_validate */
       param_uint_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamUChar", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamUChar"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_UCHAR);
   }
@@ -1078,7 +1120,7 @@ g_param_spec_types_init (void)
       param_boolean_validate,     /* value_validate */
       param_int_values_cmp,       /* values_cmp */
     };
-    type = g_param_type_register_static ("GParamBoolean", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamBoolean"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_BOOLEAN);
   }
@@ -1096,7 +1138,7 @@ g_param_spec_types_init (void)
       param_int_validate,	/* value_validate */
       param_int_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamInt", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamInt"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_INT);
   }
@@ -1114,7 +1156,7 @@ g_param_spec_types_init (void)
       param_uint_validate,	/* value_validate */
       param_uint_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamUInt", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamUInt"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_UINT);
   }
@@ -1132,7 +1174,7 @@ g_param_spec_types_init (void)
       param_long_validate,	/* value_validate */
       param_long_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamLong", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamLong"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_LONG);
   }
@@ -1150,7 +1192,7 @@ g_param_spec_types_init (void)
       param_ulong_validate,	/* value_validate */
       param_ulong_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamULong", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamULong"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_ULONG);
   }
@@ -1168,7 +1210,7 @@ g_param_spec_types_init (void)
       param_int64_validate,	/* value_validate */
       param_int64_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamInt64", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamInt64"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_INT64);
   }
@@ -1186,7 +1228,7 @@ g_param_spec_types_init (void)
       param_uint64_validate,	/* value_validate */
       param_uint64_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamUInt64", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamUInt64"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_UINT64);
   }
@@ -1204,7 +1246,7 @@ g_param_spec_types_init (void)
       param_unichar_validate,	 /* value_validate */
       param_unichar_values_cmp,	 /* values_cmp */
     };
-    type = g_param_type_register_static ("GParamUnichar", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamUnichar"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_UNICHAR);
   }
@@ -1222,7 +1264,7 @@ g_param_spec_types_init (void)
       param_enum_validate,	/* value_validate */
       param_long_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamEnum", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamEnum"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_ENUM);
   }
@@ -1240,7 +1282,7 @@ g_param_spec_types_init (void)
       param_flags_validate,	/* value_validate */
       param_ulong_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamFlags", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamFlags"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_FLAGS);
   }
@@ -1258,7 +1300,7 @@ g_param_spec_types_init (void)
       param_float_validate,	/* value_validate */
       param_float_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamFloat", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamFloat"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_FLOAT);
   }
@@ -1276,7 +1318,7 @@ g_param_spec_types_init (void)
       param_double_validate,		/* value_validate */
       param_double_values_cmp,		/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamDouble", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamDouble"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_DOUBLE);
   }
@@ -1294,7 +1336,7 @@ g_param_spec_types_init (void)
       param_string_validate,		/* value_validate */
       param_string_values_cmp,		/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamString", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamString"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_STRING);
   }
@@ -1312,7 +1354,7 @@ g_param_spec_types_init (void)
       param_param_validate,	/* value_validate */
       param_pointer_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamParam", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamParam"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_PARAM);
   }
@@ -1330,7 +1372,7 @@ g_param_spec_types_init (void)
       param_boxed_validate,	/* value_validate */
       param_boxed_values_cmp,	/* values_cmp */
     };
-    type = g_param_type_register_static ("GParamBoxed", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamBoxed"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_BOXED);
   }
@@ -1348,7 +1390,7 @@ g_param_spec_types_init (void)
       param_pointer_validate,	   /* value_validate */
       param_pointer_values_cmp,	   /* values_cmp */
     };
-    type = g_param_type_register_static ("GParamPointer", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamPointer"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_POINTER);
   }
@@ -1367,7 +1409,7 @@ g_param_spec_types_init (void)
       param_value_array_values_cmp,	/* values_cmp */
     };
     pspec_info.value_type = G_TYPE_VALUE_ARRAY;
-    type = g_param_type_register_static ("GParamValueArray", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamValueArray"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_VALUE_ARRAY);
   }
@@ -1385,7 +1427,7 @@ g_param_spec_types_init (void)
       param_object_validate,	 /* value_validate */
       param_object_values_cmp,	 /* values_cmp */
     };
-    type = g_param_type_register_static ("GParamObject", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamObject"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_OBJECT);
   }
@@ -1403,11 +1445,30 @@ g_param_spec_types_init (void)
       param_override_validate,	  /* value_validate */
       param_override_values_cmp,  /* values_cmp */
     };
-    type = g_param_type_register_static ("GParamOverride", &pspec_info);
+    type = g_param_type_register_static (g_intern_static_string ("GParamOverride"), &pspec_info);
     *spec_types++ = type;
     g_assert (type == G_TYPE_PARAM_OVERRIDE);
   }
 
+  /* G_TYPE_PARAM_GTYPE
+   */
+  {
+    GType value_type = G_TYPE_GTYPE;
+    GParamSpecTypeInfo pspec_info = {
+      sizeof (GParamSpecGType),	/* instance_size */
+      0,			/* n_preallocs */
+      param_gtype_init,		/* instance_init */
+      value_type,		/* value_type */
+      NULL,			/* finalize */
+      param_gtype_set_default,	/* value_set_default */
+      param_gtype_validate,	/* value_validate */
+      param_gtype_values_cmp,	/* values_cmp */
+    };
+    type = g_param_type_register_static (g_intern_static_string ("GParamGType"), &pspec_info);
+    *spec_types++ = type;
+    g_assert (type == G_TYPE_PARAM_GTYPE);
+  }
+
   g_assert (spec_types == spec_types_bound);
 }
 
@@ -1852,6 +1913,26 @@ g_param_spec_pointer (const gchar *name,
   return G_PARAM_SPEC (pspec);
 }
 
+GParamSpec*
+g_param_spec_gtype (const gchar *name,
+		    const gchar *nick,
+		    const gchar *blurb,
+		    GType        is_a_type,
+		    GParamFlags  flags)
+{
+  GParamSpecGType *tspec;
+  
+  tspec = g_param_spec_internal (G_TYPE_PARAM_GTYPE,
+				 name,
+				 nick,
+				 blurb,
+				 flags);
+
+  tspec->is_a_type = is_a_type;
+
+  return G_PARAM_SPEC (tspec);
+}
+
 GParamSpec*
 g_param_spec_value_array (const gchar *name,
 			  const gchar *nick,
