@@ -54,10 +54,10 @@ struct _TestData
 static void cleanup_crawlers (GMainContext *context);
 
 gboolean
-read_all (GIOChannel *channel, char *buf, int len)
+read_all (GIOChannel *channel, char *buf, gsize len)
 {
-  int bytes_read = 0;
-  int count;
+  gsize bytes_read = 0;
+  gsize count;
   GIOError err;
 
   while (bytes_read < len)
@@ -78,10 +78,10 @@ read_all (GIOChannel *channel, char *buf, int len)
 }
 
 gboolean
-write_all (GIOChannel *channel, char *buf, int len)
+write_all (GIOChannel *channel, char *buf, gsize len)
 {
-  int bytes_written = 0;
-  int count;
+  gsize bytes_written = 0;
+  gsize count;
   GIOError err;
 
   while (bytes_written < len)
@@ -167,10 +167,8 @@ adder_thread (gpointer data)
   g_source_attach (timeout_source, context);
   g_source_unref (timeout_source);
 
-  g_main_run (addr_data.loop);
+  g_main_loop_run (addr_data.loop);
 
-  g_io_channel_close (channels[0]);
-  g_io_channel_close (channels[1]);
   g_io_channel_unref (channels[0]);
   g_io_channel_unref (channels[1]);
 
@@ -178,7 +176,9 @@ adder_thread (gpointer data)
   
   g_main_loop_unref (addr_data.loop);
 
+#ifdef VERBOSE
   g_print ("Timeout run %d times\n", addr_data.count);
+#endif
 
   g_mutex_lock (context_array_mutex);
   g_ptr_array_remove (context_array, context);
@@ -204,6 +204,9 @@ io_pipe (GIOChannel **channels)
 
   channels[0] = g_io_channel_unix_new (fds[0]);
   channels[1] = g_io_channel_unix_new (fds[1]);
+
+  g_io_channel_set_close_on_unref (channels[0], TRUE);
+  g_io_channel_set_close_on_unref (channels[1], TRUE);
 }
 
 void
@@ -242,11 +245,10 @@ adder_response (GIOChannel   *source,
 	  exit (1);
 	}
 
-      g_io_channel_close (source);
-      g_io_channel_close (test_data->in);
-
       g_io_channel_unref (source);
       g_io_channel_unref (test_data->in);
+
+      g_free (test_data);
       
       return FALSE;
     }
